Module blaxel.models.function_schema_not
========================================

Classes
-------

`FunctionSchemaNot()`
:   Schema that this schema must not be
    
    Method generated by attrs for class FunctionSchemaNot.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :